#!/usr/bin/perl
#
# lantrip_report.pl 
#
# Parses database comparison reports.
#
# By Sean Mostafavi (seanm@undersea.net)
#
# Requires Mail::Sendmail;

# Change these values to reflect your setup
my $inst_dir    = '/opt/lantrip-1.0';
my @email_l 	= ('joe@example.com', 'admin@anotherexample.com');
my $tw_email	= 'tripwire@example.com';
my $domain	= 'example.com';

use strict;
use Mail::Sendmail;

my $date 	= `date +%D`;
chomp($date);

my $subject	= "Daily Tripwire report $date";
my $net_tw	= 'lantrip.pl';
my $data_d	= "$inst_dir/data/r_databases";
my $f_prefix	= 'data_out-comp-';
my @dirs	= split(/\n|\r/, `find $data_d -name \'$f_prefix*\'`);
my $message	= '';

if (-x $net_tw) {
	system($net_tw);
}

foreach my $d (@dirs) { 
	my $host = $d;

	open(FILE, "$d");
	my @file = <FILE>;
	
	$host =~ s/$f_prefix|\.db$|^.*\///g;
	$host .= ".$domain" unless ($host =~ /$domain$/);

	$message .= "\n--Tripwire Report for $host--\n";

	for (my $i = 0; $i < @file; $i++) {
		if ($file[$i] =~ /Phase 4/) {
			my ($tf, $a, $d, $ch);
			
			$tf = $1 if ($file[$i+2] =~ /\s+(\S+)\s*$/);
			$a  = $1 if ($file[$i+3] =~ /\s+(\S+)\s*$/);
			$d  = $1 if ($file[$i+4] =~ /\s+(\S+)\s*$/);
			$ch = $1 if ($file[$i+5] =~ /\s+(\S+)\s*$/);
	
			$message .= "\tTotal files scanned: $tf\n";
			$message .= "\tTotal files added since last scan: $a\n";
			$message .= "\tTotal files deleted since last scan: $d\n";
			$message .= "\tTotal files CHANGED since last scan: $ch\n";
			$message .= "\nHere's a list of the added/changed files:\n";
		}

		if ($file[$i] =~ /^added:|^changed:|^deleted:/) {
			$message .= $file[$i];
		}
	}
}

$message .= "\n*If these changes are all okay, then make sure to run:\n";
$message .= "\t/opt/tripwire/net_tripwire.pl -i <HOST>\n";
$message .= "on the central host\n\n";

foreach my $em (@email_l) {
	my %mail = ( To      => $em,
            	     From    => $tw_email,
		     Subject => $subject,
            	     Message => $message
           	   );

	sendmail(%mail) or die $Mail::Sendmail::error;
}
